@@ -1,6 +1,6 @@
 package App::JobLog::Log::Synopsis;
 {
-  $App::JobLog::Log::Synopsis::VERSION = '1.028';
+  $App::JobLog::Log::Synopsis::VERSION = '1.029';
 }
 
 # ABSTRACT: consolidates App::JobClock::Log::Event objects for display
@@ -254,8 +254,17 @@ sub time_fmt {
           if ref $se eq 'App::JobLog::Vacation::Period' && !$se->fixed;
         my $same_period = $start->hour < 12 && $end->hour < 12
           || $start->hour >= 12 && $end->hour >= 12;
-        my ( $f1, $f2 ) = ( $same_period ? '%l:%M' : '%l:%M %P', '%l:%M %P' );
-        $s = $start->strftime($f1) . ' - ' . $end->strftime($f2);
+        if (   $same_period
+            && $start->hour == $end->hour
+            && $start->minute == $end->minute )
+        {
+            $s = $start->strftime('%l:%M %P');
+        }
+        else {
+            my ( $f1, $f2 ) =
+              ( $same_period ? '%l:%M' : '%l:%M %P', '%l:%M %P' );
+            $s = $start->strftime($f1) . ' - ' . $end->strftime($f2);
+        }
     }
     else {
         $s = $start->strftime('%l:%M %P') . ' - ongoing';
@@ -276,7 +285,7 @@ App::JobLog::Log::Synopsis - consolidates App::JobClock::Log::Event objects for
 
 =head1 VERSION
 
-version 1.028
+version 1.029
 
 =head1 DESCRIPTION
 
